<?php

namespace KoiLab\WC_Force_Sells;

defined( 'ABSPATH' ) or exit;

use Automattic\WooCommerce\Utilities\FeaturesUtil;
use KoiLab\WC_Force_Sells\Admin\Admin;
use KoiLab\WC_Force_Sells\Internal\Traits\Singleton;

/**
 * Plugin class.
 *
 * @since 1.3.0
 */
class Plugin {
	use Singleton;

	/**
	 * Constructor.
	 *
	 * @since 1.3.0
	 */
	protected function __construct() {

		$this->define_constants();
		$this->init();
	}

	/**
	 * Defines constants.
	 *
	 * @since 1.3.0
	 *
	 * @return void
	 */
	private function define_constants() : void {

		$this->define( 'WC_FORCE_SELLS_VERSION', '1.5.2' );
		$this->define( 'WC_FORCE_SELLS_PATH', plugin_dir_path( WC_FORCE_SELLS_FILE ) );
		$this->define( 'WC_FORCE_SELLS_URL', plugin_dir_url( WC_FORCE_SELLS_FILE ) );
		$this->define( 'WC_FORCE_SELLS_BASENAME', plugin_basename( WC_FORCE_SELLS_FILE ) );
	}

	/**
	 * Defines a constant if not already set.
	 *
	 * @since 1.3.0
	 *
	 * @param string $name constant name
	 * @param bool|string $value constant value
	 * @return void
	 */
	private function define( string $name, $value ) : void {

		if ( ! defined( $name ) ) {
			define( $name, $value );
		}
	}

	/**
	 * Initializes the plugin.
	 *
	 * @since 1.3.0
	 *
	 * @return void
	 */
	private function init() : void {

		// load textdomain
		add_action( 'init', function() {
			load_plugin_textdomain( 'woocommerce-force-sells', false, dirname( WC_FORCE_SELLS_BASENAME ) . '/languages' );
		} );

		// declare compatibility with HPOS
		add_action( 'before_woocommerce_init', function() {
			if ( class_exists( FeaturesUtil::class ) ) {
				FeaturesUtil::declare_compatibility( 'custom_order_tables', WC_FORCE_SELLS_FILE, true );
			}
		} );

		Cart::init();

		if ( is_admin() ) {
			Admin::init();
		}

		Blocks::init();
	}

}
